@@ -1,35 +1,42 @@
 #!/bin/sh
 
-function usage
+usage()
 {
 	# Title
-	echo "Title: FFMPEG DVD-Video Export"
+	echo "Title: FFMPEG Single Pass DVD-Video"
 
 	# Usable?
 	which ffmpeg > /dev/null
-	[ $? = 0 ] && echo Status: Active || echo Status: Inactive
+	if [ $? -eq 0 ]; then
+		which mplex >/dev/null
+		[ $? -eq 0 ] && echo Status: Active || echo Status: Inactive
+	else
+		echo Status: Inactive
+	fi
 
 	# Type
 	echo Flags: single-pass file-producer
 
 	# Profiles
-	echo "Profile: Output Standard VOB"
-	echo "Profile: Output Widescreen VOB (source must be widescreen)"
+	echo "Profile: Standard VOB"
+	echo "Profile: Widescreen VOB"
 	which dvdauthor > /dev/null
-	if [ $? = 0 ]; then
-		echo "Profile: Output Standard DVD-Video directory (All only)"
-		echo "Profile: Output Widescreen DVD-Video directory (All only)"
+	if [ $? -eq 0 ]; then
+		echo "Profile: Standard DVD-Video directory (All only)"
+		echo "Profile: Widescreen DVD-Video directory (All only)"
 	fi
 }
 
-function execute
+execute()
 {
 	# Arguments
 	normalisation="$1"
 	length="$2"
 	profile="$3"
-	file="`dirname "$4"`/`basename "$4"`"
+	file="$4"
 	smil_file="$5"
+	[ "x$file" = "x" ] && file="kino_export_"`date +%Y-%m-%d_%H.%M.%S`
+	file="`dirname \"$4\"`/`basename \"$4\"`"
 
 	# Determine info arguments
 	frame_rate=`[ "$normalisation" = "pal" ] && echo 25 || echo 29.97`
@@ -40,24 +47,24 @@ function execute
 	get_chapters="`dirname $0`/extract_chapters"
 
 	# Prepare temporary files
-	M2V=`mktemp $file.XXXXXX`
-	AC3=`mktemp $file.XXXXXX`
+	M2V="`mktemp \"$file\".XXXXXX`"
+	AC3="`mktemp \"$file\".XXXXXX`"
 
 	# Run the command
 	case "$profile" in
 		"0" )
 			ffmpeg -v 0 -f dv -i pipe: -f rawvideo -pix_fmt yuv420p pipe: \
 			-vn -f $audio_format -ac 2 -ab $audio_bitrate -ar 48000 -y "$AC3" | \
-			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s $normalisation -r $normalisation -i pipe: \
+			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s "$normalisation" -r "$normalisation" -i pipe: \
 			-an -target dvd -f mpeg1video -maxrate 8000 -ildct -ilme -aspect 4:3 -y "$M2V"
-			mplex -v 0 -f 8 -o "$file" "$M2V" "$AC3"
+			mplex -v 0 -f 8 -o "$file".vob "$M2V" "$AC3"
 			;;
 		"1" )
 			ffmpeg -v 0 -f dv -i pipe: -f rawvideo -pix_fmt yuv420p pipe: \
 			-vn -f $audio_format -ac 2 -ab $audio_bitrate -ar 48000 -y "$AC3" | \
-			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s $normalisation -r $normalisation -i pipe: \
+			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s "$normalisation" -r "$normalisation" -i pipe: \
 			-an -target dvd -f mpeg1video -maxrate 8000 -ildct -ilme -aspect 16:9 -y "$M2V"
-			mplex -v 0 -f 8 -o "$file" "$M2V" "$AC3"
+			mplex -v 0 -f 8 -o "$file".vob "$M2V" "$AC3"
 			;;
 		"2" )
 			VOB=`mktemp -u $file.XXXXXX`
@@ -65,10 +72,10 @@ function execute
 			rm -rf "$file"
 			ffmpeg -v 0 -f dv -i pipe: -f rawvideo -pix_fmt yuv420p pipe: \
 			-vn -f $audio_format -ac 2 -ab $audio_bitrate -ar 48000 -y "$AC3" | \
-			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s $normalisation -r $normalisation -i pipe: \
+			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s "$normalisation" -r "$normalisation" -i pipe: \
 			-an -target dvd -f mpeg1video -maxrate 8000 -ildct -ilme -aspect 4:3 -y "$M2V"
 			mplex -v 0 -f 8 -o "$VOB" "$M2V" "$AC3" &
-			dvdauthor -o "$file" --chapters=`$get_chapters -f $frame_rate -x $smil_file` "$VOB"
+			dvdauthor -o "$file" --chapters="`$get_chapters -f $frame_rate -x $smil_file`" "$VOB"
 			dvdauthor -o "$file" -T
 			rm -f "$VOB"
 			;;
@@ -78,10 +85,10 @@ function execute
 			rm -rf "$file"
 			ffmpeg -v 0 -f dv -i pipe: -f rawvideo -pix_fmt yuv420p pipe: \
 			-vn -f $audio_format -ac 2 -ab $audio_bitrate -ar 48000 -y "$AC3" | \
-			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s $normalisation -r $normalisation -i pipe: \
+			ffmpeg -v 0 -f rawvideo -pix_fmt yuv420p -s "$normalisation" -r "$normalisation" -i pipe: \
 			-an -target dvd -f mpeg1video -maxrate 8000 -ildct -ilme -aspect 16:9 -y "$M2V"
 			mplex -v 0 -f 8 -o "$VOB" "$M2V" "$AC3" &
-			dvdauthor -o "$file" --chapters=`$get_chapters -f $frame_rate -x $smil_file` "$VOB"
+			dvdauthor -o "$file" --chapters="`$get_chapters -f $frame_rate -x $smil_file`" "$VOB"
 			dvdauthor -o "$file" -T
 			rm -f "$VOB"
 			;;
@@ -89,4 +96,4 @@ function execute
 	rm -f "$M2V" "$AC3"
 }
 
-[ "$1" = "--usage" -o "$1" = "" ] && usage $@ || execute $@
+[ "$1" = "--usage" ] || [ -z "$1" ] && usage "$@" || execute "$@"
