@@ -1,14 +1,15 @@
 #!/bin/sh
 
-function usage
+usage()
 {
 	# Title
 	echo "Title: FFMPEG MP3 Export"
 
 	# Usable?
 	which ffmpeg > /dev/null
-	[ $? = 0 ] && mp3=`ffmpeg -formats | grep Encoders: | grep mp3 | wc -l`
-	[ $mp3 = 1 ] && echo Status: Active || echo Status: Inactive
+	mp3=0
+	[ $? -eq 0 ] && mp3=`ffmpeg -formats | egrep "(Encoders:)|(.*E.*mp3)" | grep mp3 | wc -l`
+	[ "$mp3" -gt 0 ] && echo Status: Active || echo Status: Inactive
 
 	# Type
 	echo Flags: single-pass file-producer
@@ -22,13 +23,14 @@ function usage
 	echo Profile: MP3 64kb/s, 32000 khz, Mono
 }
 
-function execute
+execute()
 {
 	# Arguments
 	normalisation="$1"
 	length="$2"
 	profile="$3"
 	file="$4"
+	[ "x$file" = "x" ] && file="kino_export_"`date +%Y-%m-%d_%H.%M.%S`
 
 	# Run the command
 	case "$profile" in 
@@ -41,4 +43,4 @@ function execute
 	esac
 }
 
-[ "$1" = "--usage" -o "$1" = "" ] && usage $@ || execute $@
+[ "$1" = "--usage" ] || [ -z "$1" ] && usage "$@" || execute "$@"
