@@ -1,13 +1,13 @@
 #!/bin/sh
 
-function usage
+usage()
 {
 	# Title
 	echo "Title: rawplay playback"
 
 	# Usable?
 	which rawplay > /dev/null
-	[ $? = 0 ] && echo Status: Active || echo Status: Inactive
+	[ $? -eq 0 ] && echo Status: Active || echo Status: Inactive
 
 	# Type
 	echo Flags: single-pass 
@@ -21,7 +21,7 @@ function usage
 	echo Profile: Windowed, ESD audio output
 }
 
-function execute
+execute()
 {
 	# Arguments
 	normalisation="$1"
@@ -39,4 +39,4 @@ function execute
 	esac
 }
 
-[ "$1" = "--usage" -o "$1" = "" ] && usage $@ || execute $@
+[ "$1" = "--usage" ] || [ -z "$1" ] && usage "$@" || execute "$@"
