@@ -8,12 +8,12 @@ if [ -f /etc/kino-scripts ]; then
 	. /etc/kino-scripts
 fi
 
-if [ -f $HOME/.kino-scripts ]; then
-	. $HOME/.kino-scripts
+if [ -f "$HOME"/.kino-scripts ]; then
+	. "$HOME"/.kino-scripts
 fi
 
 if [ -n "$KINO_PUBLISH_PROJECT" ]; then
-	$KINO_PUBLISH_PROJECT "$project_file" "$project_id" "$project_title"
+	"$KINO_PUBLISH_PROJECT" "$project_file" "$project_id" "$project_title"
 else
 	echo "kino_project.sh project_file=$project_file project_id=$project_id project_title=$project_title" 
 fi
