@@ -21,6 +21,9 @@
 * Change log:
 * 
 * $Log: avi.cc,v $
+* Revision 1.27  2004/10/11 01:37:11  ddennedy
+* mutex safety locks in RIFF and AVI classes, type 2 AVI optimization, mencoder export script
+*
 * Revision 1.26  2004/01/05 03:43:11  ddennedy
 * metadata editing, deinterlace options, bugfixes and cleanups
 *
@@ -568,8 +571,10 @@ int AVIFile::GetDVFrame( Frame &frame, int frameNum )
 
 	if ( GetDVFrameInfo( offset, size, frameNum ) != 0 || size < 0 )
 		return -1;
+	pthread_mutex_lock( &file_mutex );
 	fail_if( lseek( fd, offset, SEEK_SET ) == ( off_t ) - 1 );
 	fail_neg( read( fd, frame.data, size ) );
+	pthread_mutex_unlock( &file_mutex );
 
 	return 0;
 }
@@ -1781,8 +1786,9 @@ bool AVIFile::getStreamFormat( void* data, FOURCC type )
 	FOURCC strh = make_fourcc( "strh" );
 	FOURCC strf = make_fourcc( "strf" );
 	AVIStreamHeader	avi_stream_header;
+	bool result = false;
 
-	while ( ( i = FindDirectoryEntry( strh, j++ ) ) != -1 )
+	while ( ( result == false ) && ( i = FindDirectoryEntry( strh, j++ ) ) != -1 )
 	{
 		ReadChunk( i, ( void* ) & avi_stream_header );
 		if ( avi_stream_header.fccType == type )
@@ -1790,14 +1796,16 @@ bool AVIFile::getStreamFormat( void* data, FOURCC type )
 			FOURCC chunkID;
 			int size;
 
+			pthread_mutex_lock( &file_mutex );
 			fail_neg( read( fd, &chunkID, sizeof( FOURCC ) ) );
 			if ( chunkID == strf )
 			{
 				fail_neg( read( fd, &size, sizeof( int ) ) );
 				fail_neg( read( fd, data, size ) );
-				return true;
+				result = true;
 			}
+			pthread_mutex_unlock( &file_mutex );
 		}
 	}
-	return false;
+	return result;
 }
