@@ -495,7 +495,7 @@ void
 on_redo_activate ( GtkWidget *menuitem,
                    gpointer user_data )
 {
-	processCommand( "ctrl+r" );
+	processCommand( "Ctrl+R" );
 	gtk_widget_grab_focus( lookup_widget( menuitem, "eventbox_edit_drawingarea" ) );
 }
 
@@ -678,62 +678,8 @@ on_main_window_scroll_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data)
 {
-	if ( event->scroll.state & GDK_SHIFT_MASK )
-	{
-		if ( event->scroll.direction == GDK_SCROLL_UP )
-			videoBack( );
-		else if ( event->scroll.direction == GDK_SCROLL_DOWN )
-			videoForward( );
-	}
-	else if ( event->scroll.state & GDK_CONTROL_MASK )
-	{
-		int speedTable[] = {
-			0,
-			8,  10, 16, 20, 33, 50, 75,
-			100,
-			200, 300, 400, 500, 800, 1200,
-			3001 };
-		int i = 0;
-		int speed;
-		int direction;
-
-		if ( g_nav_ctl.active == FALSE )
-		{
-			speed = 8;
-			direction = ( event->scroll.direction == GDK_SCROLL_UP ? -1 : 1 );
-		}
-		else if ( g_nav_ctl.step == 0 )
-		{
-			speed = 100 / ( g_nav_ctl.rate < 0 ? -g_nav_ctl.rate : g_nav_ctl.rate );
-			speed = speed == 100 ? 75 : speed;
-			direction = g_nav_ctl.rate < 0 ? -1 : 1;
-		}
-		else
-		{
-			speed = ( g_nav_ctl.step < 0 ? -g_nav_ctl.step : g_nav_ctl.step ) * 100;
-			direction = g_nav_ctl.step < 0 ? -1 : 1;
-		}
-		
-		while ( i < 16 && speedTable[ i ] < speed )
-			++i;
-		
-		i *= direction;
-		//fprintf( stderr, "speed %d direction %d i %d\n", speed, direction, i );
-		
-		if ( event->scroll.direction == GDK_SCROLL_UP )
-			videoShuttle( -- i );
-		else if ( event->scroll.direction == GDK_SCROLL_DOWN )
-			videoShuttle( ++ i );
-	}
-	else
-	{
-		if ( event->scroll.direction == GDK_SCROLL_UP )
-			videoBackBy( -10 );
-		else if ( event->scroll.direction == GDK_SCROLL_DOWN )
-			videoForwardBy( 10 );
-	}
-
-  return FALSE;
+	handleMouseScroll( event ); 
+	return FALSE;
 }
 
 
