@@ -534,17 +534,37 @@ XvDisplayer::XvDisplayer( GtkWidget *drawingarea, int width, int height, bool is
 
 		if ( gotPort )
 		{
-			unsigned int num;
+			int num;
+			unsigned int unum;
 			XvEncodingInfo *enc;
-			XvQueryEncodings( display, grabbedPort, &num, &enc );
-			for ( unsigned int index = 0; index < num; index ++ )
+			
+			XvQueryEncodings( display, grabbedPort, &unum, &enc );
+			for ( unsigned int index = 0; index < unum; index ++ )
 			{
-				printf( ">>> %d: %s, %ldx%ld rate = %d/%d\n", index, enc->name,
+				fprintf( stderr, ">>> %d: %s, %ldx%ld rate = %d/%d\n", index, enc->name,
 				        enc->width, enc->height, enc->rate.numerator,
 				        enc->rate.denominator );
 			}
-			// Set the chroma key color to very dark gray (prettier than bright blue)
-			//XvSetPortAttribute( display, port, XInternAtom(display, "XV_COLORKEY", 0), 0x010102);
+			
+			XvAttribute *xvattr = XvQueryPortAttributes( display, port, &num );
+			for ( int k = 0; k < num; k++ )
+			{
+				if ( xvattr[k].flags & XvSettable ) 
+				{
+					if ( strcmp( xvattr[k].name, "XV_AUTOPAINT_COLORKEY") == 0 )
+					{
+						Atom val_atom = XInternAtom( display, xvattr[k].name, False );
+						if ( XvSetPortAttribute( display, port, val_atom, 1 ) != Success )
+							fprintf(stderr, "Couldn't set Xv attribute %s\n", xvattr[k].name);
+					}
+					else if (  strcmp( xvattr[k].name, "XV_COLORKEY") == 0 )
+					{
+						Atom val_atom = XInternAtom( display, xvattr[k].name, False );
+						if ( XvSetPortAttribute( display, port, val_atom, 0x010102 ) != Success )
+							fprintf(stderr, "Couldn't set Xv attribute %s\n", xvattr[k].name);
+					}
+				}
+			}
 		}
 
 		if ( gotPort )
@@ -561,6 +581,7 @@ XvDisplayer::XvDisplayer( GtkWidget *drawingarea, int width, int height, bool is
 			{
 				gotPort = false;
 			}
+			XSync( display, false );
 			shmctl( shmInfo.shmid, IPC_RMID, 0 );
 #if 0
 
@@ -739,4 +760,3 @@ Displayer *FindDisplayer::getDisplayer( GtkWidget *drawingarea, int width, int h
 
 	return display;
 }
-
