@@ -243,7 +243,7 @@ bool FileHandler::WriteFrame( const Frame& frame )
 				struct timeval tv;
 				struct timezone tz;
 				gettimeofday( &tv, &tz );
-				localtime_r( &tv.tv_sec, &date );
+				localtime_r( static_cast< const time_t * >( &tv.tv_sec ), &date );
 			}
 			sb << setfill( '0' )
 			<< setw( 4 ) << date.tm_year + 1900 << '.'
@@ -334,7 +334,7 @@ RawHandler::RawHandler() : fd( -1 )
 
 RawHandler::~RawHandler()
 {
-	/* empty body */
+	Close();
 }
 
 
@@ -436,9 +436,21 @@ AVIHandler::AVIHandler( int format ) : avi( NULL ), aviFormat( format ), isOpenD
 
 AVIHandler::~AVIHandler()
 {
-	// Just in case it hasn't been deleted
-	delete avi;
+	if ( audioBuffer != NULL )
+	{
+		delete audioBuffer;
+		audioBuffer = NULL;
+	}
+	for ( int c = 0; c < 4; c++ )
+	{
+		if ( audioChannels[ c ] != NULL )
+		{
+			delete audioChannels[ c ];
+			audioChannels[ c ] = NULL;
+		}
+	}
 
+	delete avi;
 }
 
 void AVIHandler::SetSampleFrame( const Frame& sample )
@@ -521,8 +533,7 @@ int AVIHandler::Write( const Frame& frame )
 	assert( avi != NULL );
 	try
 	{
-		avi->WriteFrame( frame ) ? 0 : -1;
-		return 0;
+		return avi->WriteFrame( frame ) ? 0 : -1;
 	}
 	catch (...)
 	{
@@ -605,44 +616,54 @@ int AVIHandler::GetFrame( Frame &frame, int frameNum )
 	int result = avi->GetDVFrame( frame, frameNum );
 	if ( result == 0 )
 	{
-		WAVEFORMATEX wav;
-
 		/* get the audio from the audio stream, if available */
-		if ( avi->getStreamFormat( ( void* ) & wav, make_fourcc( "auds" ) ) )
+		if ( aviFormat == AVI_DV2_FORMAT )
 		{
-			int n;
-			AudioInfo info;
+			WAVEFORMATEX wav;
 
-			if ( ! isFullyInitialized )
+			if ( ! isFullyInitialized && 
+				 avi->getStreamFormat( ( void* ) &wav, make_fourcc( "auds" ) ) )
 			{
 				if ( channels > 0 && channels < 5 )
 				{
+					// Allocate interleaved audio buffer
 					audioBuffer = new int16_t[ 2 * DV_AUDIO_MAX_SAMPLES * channels ];
 
+					// Allocate non-interleaved audio buffers
 					for ( int c = 0; c < channels; c++ )
 						audioChannels[ c ] = new int16_t[ 2 * DV_AUDIO_MAX_SAMPLES ];
+					
+					// Get the audio parameters from AVI for subsequent calls to method
+					audioInfo.channels = wav.nChannels;
+					audioInfo.frequency = wav.nSamplesPerSec;
+
+					// Skip initialization on subsequent calls to method
 					isFullyInitialized = true;
+					cerr << ">>> using audio from separate AVI audio stream" << endl;
 				}
-				cerr << ">>> using audio from separate AVI audio stream" << endl;
 			}
 
-			n = avi->getFrame( audioBuffer, frameNum, make_fourcc( "01wb" ) );
+			// Get the frame from AVI
+			int n = avi->getFrame( audioBuffer, frameNum, make_fourcc( "01wb" ) );
 			if ( n > 0 )
 			{
+				// Temporary pointer to audio scratch buffer
 				int16_t * s = audioBuffer;
 
-				info.samples = n / wav.nChannels / sizeof( int16_t );
-				info.channels = wav.nChannels;
-				info.frequency = wav.nSamplesPerSec;
-
-				for ( int n = 0; n < info.samples; ++n )
-					for ( int i = 0; i < info.channels; i++ )
+				// Determine samples in this frame
+				audioInfo.samples = n / audioInfo.channels / sizeof( int16_t );
+				
+				// Convert interleaved audio into non-interleaved
+				for ( int n = 0; n < audioInfo.samples; ++n )
+					for ( int i = 0; i < audioInfo.channels; i++ )
 						audioChannels[ i ][ n ] = *s++;
 
-				frame.EncodeAudio( info, audioChannels );
+				// Write interleaved audio into frame
+				frame.EncodeAudio( audioInfo, audioChannels );
 			}
 		}
 
+		// Parse important metadata in DV bitstream
 		frame.ExtractHeader();
 	}
 	return result;
