@@ -1303,6 +1303,21 @@ bool Frame::EncodeAudio( AudioInfo &info, int16_t **channels )
 	return ( result != -1 );
 }
 
+int Frame::CalculateNumberSamples( int frequency, int iteration )
+{
+#ifdef LIBDV_HAS_SAMPLE_CALCULATOR
+	dv_encoder_t * encoder = dv_encoder_new( FALSE, FALSE, FALSE );
+	int samples = dv_calculate_samples( encoder, frequency, iteration );
+	dv_encoder_free( encoder );
+
+#else
+	int samples = info->frequency / ( info->isPAL ? 25 : 30 );
+#endif
+	
+	return samples;
+}
+
+
 #endif
 
 /** Constructor for the resampler.
@@ -1459,9 +1474,9 @@ void SrcAudioResample::Resample( int16_t *input, int input_rate, int channels, i
 		if ( sample < -1.0 )
 			sample = -1.0;
 		if ( sample >= 0 )
-			output[ i ] = lrint( 32767.0 * sample );
+			output[ i ] = ( long int )( 32767.0 * sample );
 		else
-			output[ i ] = lrint( 32768.0 * sample );
+			output[ i ] = ( long int )( 32768.0 * sample );
 	}
 }
 
