@@ -36,12 +36,10 @@ using std::endl;
 FrameDisplayer::FrameDisplayer() : 
 	displayer( NULL ), 
 	resampler( NULL ), 
+	audio_device( NULL ),
 	audio_device_avail( FALSE ),
 	prevIsWide( false )
 {
-	Preferences & prefs = Preferences::getInstance();
-	if ( prefs.enableAudio )
-		audio_device = dv_oss_new();
 	for ( gint i = 0; i < 4; i++ )
 		audio_buffers[ i ] = ( gint16 * ) malloc( 2 * DV_AUDIO_MAX_SAMPLES * sizeof( gint16 ) );
 }
@@ -55,32 +53,45 @@ FrameDisplayer::~FrameDisplayer()
 	if ( resampler != NULL )
 		delete resampler;
 
+	for ( gint i = 0; i < 4; i++ )
+		free( audio_buffers[ i ] );
+	
+	CloseSound();
+}
+
+
+void FrameDisplayer::CloseSound()
+{
 	if ( audio_device_avail )
 	{
 		dv_oss_close( audio_device );
 		audio_device_avail = FALSE;
 		audio_device = NULL;
 	}
-	for ( gint i = 0; i < 4; i++ )
-		free( audio_buffers[ i ] );
 }
 
+
 void FrameDisplayer::PutSound( Frame &frame )
 {
 	static Preferences & prefs = Preferences::getInstance();
-	if ( prefs.enableAudio && audio_device != NULL )
+	if ( prefs.enableAudio )
 	{
-		if ( !audio_device_avail &&
-		        ( audio_sampling_rate = dv_oss_init( frame.decoder->audio, audio_device ) ) != 0 )
-			audio_device_avail = TRUE;
-		if ( audio_device_avail )
+		if ( audio_device == NULL )
+			audio_device = dv_oss_new();
+		if ( audio_device != NULL )
 		{
-			if ( resampler == NULL )
-				resampler = AudioResampleFactory::createAudioResample(
-				                AUDIO_RESAMPLE_SRC_SINC_FASTEST, audio_sampling_rate );
-			resampler->Resample( frame );
-			if ( resampler->size )
-				dv_oss_player( audio_device, resampler->output, resampler->size );
+			if ( !audio_device_avail &&
+					( audio_sampling_rate = dv_oss_init( frame.decoder->audio, audio_device ) ) != 0 )
+				audio_device_avail = TRUE;
+			if ( audio_device_avail )
+			{
+				if ( resampler == NULL )
+					resampler = AudioResampleFactory::createAudioResample(
+									AUDIO_RESAMPLE_SRC_SINC_FASTEST, audio_sampling_rate );
+				resampler->Resample( frame );
+				if ( resampler->size )
+					dv_oss_player( audio_device, resampler->output, resampler->size );
+			}
 		}
 	}
 }
@@ -101,6 +112,7 @@ void FrameDisplayer::Put( Frame &frame, GtkWidget *drawingarea, gboolean no_audi
 				input = DISPLAY_YUV;
 				break;
 			case DISPLAY_RGB:
+			default:
 				frame.ExtractPreviewRGB( pixels );
 				input = DISPLAY_RGB;
 				break;
