@@ -36,8 +36,9 @@
 #include <malloc.h>
 #include <math.h>
 
+#undef FANCY
 #define ENHANCED_SCALE_CLASS(w)  GTK_ENHANCED_SCALE_CLASS ( G_OBJECT_GET_CLASS( G_OBJECT( w )  ) ) 
-/* #define DEBUG */
+/*#define DEBUG*/
 
 static void gtk_enhanced_scale_class_init ( GtkEnhancedScaleClass *klass );
 static void gtk_enhanced_scale_init ( GtkEnhancedScale *enhanced_scale );
@@ -54,9 +55,7 @@ static void gtk_enhanced_scale_draw_trough ( GtkEnhancedScale *enhanced_scale );
 static void gtk_enhanced_scale_slider_update ( GtkEnhancedScale *enhanced_scale, gint i );
 static void gtk_enhanced_scale_trough_hdims ( GtkEnhancedScale *enhanced_scale, gint *left, gint *right, gint i );
 static void gtk_enhanced_scale_get_slider_position( GtkEnhancedScale *enhanced_scale, gint *x, gint *y, gint i );
-static gint gtk_enhanced_scale_get_stepper_spacing( GtkWidget *widget );
 static gint gtk_enhanced_scale_get_trough_border( GtkWidget *widget );
-/*static gint gtk_enhanced_scale_get_stepper_size(GtkWidget *widget);*/
 static gint gtk_enhanced_scale_get_slider_width( GtkWidget *widget );
 static gint gtk_enhanced_scale_button_press( GtkWidget *widget, GdkEventButton *event );
 static gint gtk_enhanced_scale_button_release( GtkWidget *widget, GdkEventButton *event );
@@ -126,8 +125,6 @@ static void gtk_enhanced_scale_class_init ( GtkEnhancedScaleClass *class )
 
 	class->slider_width = 32;
 	class->trough_width = 10;
-	class->stepper_size = 11;
-	class->stepper_slider_spacing = 1;
 	class->trough = 1;
 	class->slider = 2;
 	class->arrow_width = 20;
@@ -264,7 +261,7 @@ static void gtk_enhanced_scale_realize ( GtkWidget *widget )
 	                           GDK_POINTER_MOTION_HINT_MASK );
 	enhanced_scale->slider[ 0 ] = gdk_window_new ( enhanced_scale->trough,
 	                              &attributes, attributes_mask );
-	attributes.y += ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_height + ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough_width;
+	attributes.y += ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_height + ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough_width - 1;
 	attributes.width = ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_width / 2;
 	for ( i = 1;i < enhanced_scale->num_adjustments;i++ )
 		enhanced_scale->slider[ i ] = gdk_window_new ( enhanced_scale->trough,
@@ -499,7 +496,7 @@ static void gtk_enhanced_scale_draw_trough ( GtkEnhancedScale *enhanced_scale )
 			gdk_draw_rectangle( enhanced_scale->trough, GTK_WIDGET ( enhanced_scale ) ->style->mid_gc[ GTK_STATE_NORMAL ],
 			                    TRUE, ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_width / 2 + 1,
 			                    ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_height + b + 1,
-			                    right - left,
+			                    right - left + 1,
 			                    ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough_width - 2
 			                  );
 
@@ -511,7 +508,7 @@ static void gtk_enhanced_scale_draw_trough ( GtkEnhancedScale *enhanced_scale )
 				gdk_draw_rectangle( enhanced_scale->trough,
 				                    GTK_WIDGET ( enhanced_scale ) ->style->mid_gc[ GTK_STATE_SELECTED ],
 				                    TRUE,
-				                    x + ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_width / 2 + 1,
+				                    x + ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_width / 2,
 				                    ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_height + b + 1,
 				                    x2 - x - ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_width / 2,
 				                    ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough_width - 2
@@ -536,7 +533,7 @@ static void gtk_enhanced_scale_draw_trough ( GtkEnhancedScale *enhanced_scale )
 			gdk_draw_rectangle( enhanced_scale->trough, GTK_WIDGET ( enhanced_scale ) ->style->mid_gc[ GTK_STATE_NORMAL ],
 			                    TRUE, ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_width / 2 + 1,
 			                    ENHANCED_SCALE_CLASS ( enhanced_scale ) ->arrow_height + b + 1,
-			                    right - left,
+			                    right - left + 1,
 			                    ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough_width - 2
 			                  );
 		}
@@ -563,10 +560,9 @@ static void gtk_enhanced_scale_draw_trough ( GtkEnhancedScale *enhanced_scale )
 					              );
 
 				}
-
+#ifdef FANCY
 		/* frame position */
 		gtk_enhanced_scale_get_slider_position( enhanced_scale, &x, &y, 0 );
-#ifdef FANCY
 		gtk_paint_box (GTK_WIDGET (enhanced_scale)->style,
                          enhanced_scale->trough, GTK_STATE_NORMAL,
                          GTK_SHADOW_OUT, NULL, GTK_WIDGET(enhanced_scale),
@@ -668,19 +664,6 @@ static void gtk_enhanced_scale_draw_slider ( GtkEnhancedScale *enhanced_scale, g
 		}
 		gdk_draw_polygon( enhanced_scale->slider[ i ],
 		                  GTK_WIDGET( enhanced_scale ) ->style->bg_gc[ state_type ], TRUE, points, 3 );
-		/*
-				gtk_paint_polygon( GTK_WIDGET(enhanced_scale)->style, enhanced_scale->slider[i],
-					state_type,	GTK_SHADOW_NONE, NULL, GTK_WIDGET(enhanced_scale), NULL,
-					points, 3, TRUE );
-				gtk_paint_arrow( GTK_WIDGET(enhanced_scale)->style, enhanced_scale->slider[i],
-					state_type, 
-					(enhanced_scale->clicked_slider == i ? GTK_SHADOW_IN : GTK_SHADOW_OUT),
-					NULL, GTK_WIDGET(enhanced_scale), NULL,
-					(i==0)? GTK_ARROW_DOWN : GTK_ARROW_UP, TRUE, 0, 0, 
-					ENHANCED_SCALE_CLASS (enhanced_scale)->arrow_width, 
-					ENHANCED_SCALE_CLASS (enhanced_scale)->arrow_height
-				);
-		*/
 	}
 }
 
@@ -774,7 +757,7 @@ static void gtk_enhanced_scale_slider_update ( GtkEnhancedScale *enhanced_scale,
 			x = right;
 
 		gdk_window_move ( enhanced_scale->slider[ i ], x,
-		                  trough_border + ( i > 0 ? ENHANCED_SCALE_CLASS( enhanced_scale ) ->arrow_height + ENHANCED_SCALE_CLASS( enhanced_scale ) ->trough_width : 0 ) );
+		                  trough_border + ( i > 0 ? ENHANCED_SCALE_CLASS( enhanced_scale ) ->arrow_height + ENHANCED_SCALE_CLASS( enhanced_scale ) ->trough_width - 1 : 0 ) );
 	}
 }
 
@@ -784,7 +767,6 @@ static void gtk_enhanced_scale_trough_hdims ( GtkEnhancedScale *enhanced_scale,
 	gint slider_length;
 	gint tleft;
 	gint tright;
-	gint stepper_spacing;
 	gint trough_border;
 
 	g_return_if_fail ( enhanced_scale != NULL );
@@ -793,7 +775,6 @@ static void gtk_enhanced_scale_trough_hdims ( GtkEnhancedScale *enhanced_scale,
 	gdk_window_get_size ( enhanced_scale->slider[ 0 ], &slider_length, NULL );
 
 	trough_border = gtk_enhanced_scale_get_trough_border( GTK_WIDGET( enhanced_scale ) );
-	stepper_spacing = gtk_enhanced_scale_get_stepper_spacing( GTK_WIDGET( enhanced_scale ) );
 
 	tleft = trough_border;
 	tright = trough_width - slider_length + trough_border;
@@ -819,14 +800,6 @@ static void gtk_enhanced_scale_get_slider_position( GtkEnhancedScale *enhanced_s
 	gdk_window_get_position( enhanced_scale->slider[ i ], x, y );
 }
 
-static gint gtk_enhanced_scale_get_stepper_spacing( GtkWidget *widget )
-{
-	/*return gtk_style_get_prop_experimental (widget->style,
-		"GtkEnhancedScale::stepper_spacing",
-		ENHANCED_SCALE_CLASS (widget)->stepper_slider_spacing);*/ 
-	return ENHANCED_SCALE_CLASS ( widget ) ->stepper_slider_spacing;
-}
-
 static gint gtk_enhanced_scale_get_trough_border( GtkWidget *widget )
 {
 	/*return gtk_style_get_prop_experimental (widget->style,
@@ -835,13 +808,6 @@ static gint gtk_enhanced_scale_get_trough_border( GtkWidget *widget )
 	return widget->style->ythickness;
 }
 
-/*static gint gtk_enhanced_scale_get_stepper_size(GtkWidget *widget)
-{
-	return gtk_style_get_prop_experimental (widget->style,
-		"GtkEnhancedScale::stepper_size",
-		ENHANCED_SCALE_CLASS (widget)->stepper_size);
-}*/
-
 static gint gtk_enhanced_scale_get_slider_width( GtkWidget *widget )
 {
 	/*return gtk_style_get_prop_experimental (widget->style,
@@ -876,14 +842,11 @@ static gint gtk_enhanced_scale_button_press( GtkWidget *widget, GdkEventButton *
 
 	if ( event->window == enhanced_scale->trough )
 	{
-		gint x, y, n, left, right;
-		gtk_enhanced_scale_get_slider_position( enhanced_scale, &x, &y, enhanced_scale->active_slider );
-#ifdef DEBUG
-
-		printf( "Source: trough. Active slider: %d (pos: %d,%d). Click position: %d,%d.\n",
-		        enhanced_scale->active_slider, x, y, ( int ) ( event->x ), ( int ) ( event->y ) );
-#endif
-
+		gint x, y;
+		
+#if 0   /* old behaviour to nudge around the sliders by clicking around them. */
+		gint n, left, right;
+		//gtk_enhanced_scale_get_slider_position( enhanced_scale, &x, &y, enhanced_scale->active_slider );
 		gtk_enhanced_scale_trough_hdims ( enhanced_scale, &left, &right,
 		                                  enhanced_scale->active_slider );
 		n = ( GTK_ADJUSTMENT( enhanced_scale->adjustment[ enhanced_scale->active_slider ] ) ->page_increment )
@@ -899,6 +862,16 @@ static gint gtk_enhanced_scale_button_press( GtkWidget *widget, GdkEventButton *
 		{
 			gtk_enhanced_scale_motion_x( enhanced_scale, -n, enhanced_scale->active_slider );
 		}
+#endif
+#ifdef DEBUG
+
+		printf( "Source: trough. Active slider: %d (pos: %d,%d). Click position: %d,%d.\n",
+		        enhanced_scale->active_slider, x, y, ( int ) ( event->x ), ( int ) ( event->y ) );
+#endif
+		/* New behaviour: a click anywhere not on arrow moves slider 0 to the click spot. */
+		gtk_enhanced_scale_get_slider_position(enhanced_scale, &x, &y, 0 );
+		gtk_enhanced_scale_motion_x( enhanced_scale, event->x - x - 
+			ENHANCED_SCALE_CLASS( enhanced_scale )->arrow_width/2 + 1, 0 );
 	}
 	else
 		for ( i = 0;i < enhanced_scale->num_adjustments;i++ )
@@ -907,13 +880,13 @@ static gint gtk_enhanced_scale_button_press( GtkWidget *widget, GdkEventButton *
 			gtk_enhanced_scale_get_slider_position( enhanced_scale, &x, &y, i );
 			if ( event->window == enhanced_scale->slider[ i ] )
 			{
-				enhanced_scale->active_slider = i;
 #ifdef DEBUG
 
 				printf( "Source: slider %d (pos: %d,%d)\n", i, x, y );
 #endif
-
+				enhanced_scale->active_slider = i;
 				enhanced_scale->clicked_slider = i;
+				break;
 			}
 		}
 	return TRUE;
@@ -929,17 +902,17 @@ static gint gtk_enhanced_scale_button_release( GtkWidget *widget, GdkEventButton
 
 	enhanced_scale = GTK_ENHANCED_SCALE ( widget );
 
-	enhanced_scale->x_click_point = 0;
 #ifdef DEBUG
-
 	printf( "Button released" );
 	if ( enhanced_scale->clicked_slider != -1 )
 		printf( " - slider %d unselected", enhanced_scale->clicked_slider );
 	printf( "\n" );
 #endif
 
+	enhanced_scale->x_click_point = 0;
 	enhanced_scale->clicked_slider = -1;
 	gtk_widget_queue_draw ( widget );
+
 	return TRUE;
 }
 
@@ -1121,14 +1094,16 @@ static gint gtk_enhanced_scale_enter_notify( GtkWidget *widget, GdkEventCrossing
 		enhanced_scale->in_child = ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough;
 	}
 	else
+	{
 		for ( i = 0;i < enhanced_scale->num_adjustments;i++ )
+		{
 			if ( event->window == enhanced_scale->slider[ i ] )
 			{
 				enhanced_scale->in_child = ENHANCED_SCALE_CLASS ( enhanced_scale ) ->slider;
-				if ( ( enhanced_scale->click_child == 0 ) ||
-				        ( enhanced_scale->click_child == ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough ) )
-					gtk_enhanced_scale_draw_slider ( enhanced_scale, i );
+				break;
 			}
+		}
+	}
 
 	return TRUE;
 }
@@ -1136,27 +1111,14 @@ static gint gtk_enhanced_scale_enter_notify( GtkWidget *widget, GdkEventCrossing
 static gint gtk_enhanced_scale_leave_notify( GtkWidget *widget, GdkEventCrossing *event )
 {
 	GtkEnhancedScale * enhanced_scale;
-	gint i;
 
 	g_return_val_if_fail ( widget != NULL, FALSE );
 	g_return_val_if_fail ( GTK_IS_ENHANCED_SCALE ( widget ), FALSE );
 	g_return_val_if_fail ( event != NULL, FALSE );
 
 	enhanced_scale = GTK_ENHANCED_SCALE ( widget );
-
 	enhanced_scale->in_child = 0;
-
-	if ( event->window == enhanced_scale->trough )
-	{}
-	else
-		for ( i = 0;i < enhanced_scale->num_adjustments;i++ )
-			if ( event->window == enhanced_scale->slider[ i ] )
-			{
-				if ( ( enhanced_scale->click_child == 0 ) ||
-				        ( enhanced_scale->click_child == ENHANCED_SCALE_CLASS ( enhanced_scale ) ->trough ) )
-					gtk_enhanced_scale_draw_slider ( enhanced_scale, i );
-			}
-
+	
 	return TRUE;
 }
 
@@ -1167,13 +1129,11 @@ static gint gtk_enhanced_scale_focus_in( GtkWidget *widget, GdkEventFocus *event
 	g_return_val_if_fail ( event != NULL, FALSE );
 
 	GTK_WIDGET_SET_FLAGS ( widget, GTK_HAS_FOCUS );
-	gtk_widget_queue_draw ( widget );
+	//gtk_widget_queue_draw ( widget );
 #ifdef DEBUG
 
 	printf( "focus_in\n" );
 #endif
-
-	gtk_widget_queue_draw ( widget );
 	return FALSE;
 }
 
@@ -1184,13 +1144,11 @@ static gint gtk_enhanced_scale_focus_out( GtkWidget *widget, GdkEventFocus *even
 	g_return_val_if_fail ( event != NULL, FALSE );
 
 	GTK_WIDGET_UNSET_FLAGS ( widget, GTK_HAS_FOCUS );
-	gtk_widget_queue_draw ( widget );
+	//gtk_widget_queue_draw ( widget );
 #ifdef DEBUG
 
 	printf( "focus_out\n" );
 #endif
-
-	gtk_widget_queue_draw ( widget );
 	return FALSE;
 }
 
@@ -1228,10 +1186,18 @@ static void gtk_enhanced_scale_adjustment_value_changed( GtkAdjustment *adjustme
 
 	for ( i = 0;i < enhanced_scale->num_adjustments;i++ )
 	{
-		//if(adjustment == GTK_ADJUSTMENT(enhanced_scale->adjustment[i]))
-		gtk_enhanced_scale_slider_update ( enhanced_scale, i );
+		if ( adjustment == GTK_ADJUSTMENT( enhanced_scale->adjustment[i] ) )
+		{
+			gtk_enhanced_scale_slider_update( enhanced_scale, i );
+			if ( i > 0 )
+				/* selection changed, need to redraw all */
+				gtk_enhanced_scale_draw ( GTK_WIDGET( enhanced_scale ), NULL );
+			else
+				/* only need to update position slider */
+				gtk_enhanced_scale_draw_slider( enhanced_scale, i );
+			break;
+		}
 	}
-	gtk_enhanced_scale_draw ( GTK_WIDGET( enhanced_scale ), NULL );
 }
 
 void gtk_enhanced_scale_set_breaks( GtkWidget *widget, GArray *breaks )
