@@ -60,6 +60,7 @@ using std::endl;
 #include <sys/ioctl.h>
 #include <sys/mman.h>
 #include <sys/poll.h>
+#include <errno.h>
 
 #include <libraw1394/raw1394.h>
 #include <libraw1394/csr.h>
@@ -76,29 +77,6 @@ using std::endl;
 #include "message.h"
 #include "commands.h"
 
-/* static member variables.
- 
-   I tried non-static member variables first but they did not work
-   when used by two threads. I have no idea why though.
- 
-   CY: Because are threads are running on static methods :-/ - to
-   remove it we need to pass the object pointer into the callback
-   method (somehow).
-*/
-
-int IEEE1394Reader::droppedFrames;
-pthread_mutex_t IEEE1394Reader::mutex;
-pthread_mutex_t IEEE1394Reader::condition_mutex;
-pthread_cond_t IEEE1394Reader::condition;
-Frame *IEEE1394Reader::currentFrame;
-deque < Frame* > IEEE1394Reader::inFrames;
-deque < Frame* > IEEE1394Reader::outFrames;
-raw1394handle_t raw1394Reader::handle;
-unsigned char *dv1394Reader::m_dv1394_map;
-int dv1394Reader::m_dv1394_fd;
-raw1394handle_t AVC::avc_handle;
-pthread_mutex_t AVC::avc_mutex;
-
 
 /** Initializes the IEEE1394Reader object.
  
@@ -109,7 +87,6 @@ pthread_mutex_t AVC::avc_mutex;
     The object contains a list of empty frames, which are allocated
     here. 50 frames (2 seconds) should be enough in most cases.
  
-    \param p the number of the interface card to use
     \param c the iso channel number to use
     \param bufSize the number of frames to allocate for the frames buffer
  */
@@ -222,7 +199,8 @@ void IEEE1394Reader::DoneWithFrame( Frame* frame )
 /** Throw away all currently available frames.
  
     All frames in the outFrames queue are put back to the inFrames
-    queue.  Also the currentFrame is put back too.  */
+    queue. Also the currentFrame is put back too.
+*/
 
 void IEEE1394Reader::Flush()
 {
@@ -308,9 +286,9 @@ bool raw1394Reader::StartThread()
 	currentFrame = NULL;
 	if ( Open() && StartReceive() )
 	{
-		pthread_create( &thread, NULL, Thread, this );
-		pthread_mutex_unlock( &mutex );
 		isRunning = true;
+		pthread_create( &thread, NULL, ThreadProxy, this );
+		pthread_mutex_unlock( &mutex );
 		return true;
 	}
 	else
@@ -329,11 +307,6 @@ bool raw1394Reader::StartThread()
     canceled, we turn off iso receive and close the ieee1394
     subsystem.  We also remove all frames in the outFrames queue that
     have not been processed until now.
- 
-    \bugs It is not clear what happens if no data is being sent by the
-    camcorder. Will we still hit the pthread_testcancel function in
-    this case?
- 
 */
 
 void raw1394Reader::StopThread()
@@ -341,15 +314,14 @@ void raw1394Reader::StopThread()
 	if ( isRunning )
 	{
 		pthread_mutex_lock( &mutex );
-		pthread_cancel( thread );
+		isRunning = false;
 		pthread_join( thread, NULL );
+		pthread_mutex_unlock( &mutex );
 		StopReceive();
 		Close();
 		Flush();
-		pthread_mutex_unlock( &mutex );
 		TriggerAction( );
 	}
-	isRunning = false;
 }
 
 
@@ -382,7 +354,8 @@ bool raw1394Reader::Open()
 		fail_neg( numcards = raw1394_get_port_info( handle, pinf, 16 ) );
 		fail_neg( raw1394_set_port( handle, port ) );
 
-		oldhandler = raw1394_set_iso_handler( handle, channel, Handler );
+		oldhandler = raw1394_set_iso_handler( handle, channel, HandlerProxy );
+		raw1394_set_userdata( handle, this );
 
 		success = true;
 	}
@@ -467,8 +440,13 @@ void raw1394Reader::StopReceive()
  
 */
 
-int raw1394Reader::Handler( raw1394handle_t handle, int channel, size_t length,
-                            quadlet_t *data )
+int raw1394Reader::HandlerProxy( raw1394handle_t handle, int channel, size_t length, quadlet_t *data )
+{
+	raw1394Reader *self = static_cast< raw1394Reader* >( raw1394_get_userdata( handle ) );
+	return self->Handler( channel, length, data );
+}
+
+int raw1394Reader::Handler( int channel, size_t length, quadlet_t *data )
 {
 	/* skip empty packets */
 
@@ -581,14 +559,33 @@ int raw1394Reader::Handler( raw1394handle_t handle, int channel, size_t length,
     but only in the pthread_testcancel() function.
  
 */
-void* raw1394Reader::Thread( void* arg )
+void* raw1394Reader::ThreadProxy( void* arg )
 {
-	raw1394Reader * theReader = ( raw1394Reader* ) arg;
+	raw1394Reader* self = static_cast< raw1394Reader* >( arg );
+	return self->Thread();
+}
 
-	while ( true )
+void* raw1394Reader::Thread()
+{
+	struct pollfd raw1394_poll;
+	int result;
+		
+	raw1394_poll.fd = raw1394_get_fd( handle );
+	raw1394_poll.events = POLLIN | POLLERR | POLLHUP | POLLPRI;
+
+	while ( isRunning )
 	{
-		raw1394_loop_iterate( theReader->handle );
-		pthread_testcancel();
+		while ( ( result = poll( &raw1394_poll, 1, 200 ) ) < 0 )
+		{
+			if ( !( errno == EAGAIN || errno == EINTR ) )
+			{
+				perror( "error: raw1394 poll" );
+				break;
+			}
+		}
+		if ( result > 0 && ( ( raw1394_poll.revents & POLLIN )
+		        || ( raw1394_poll.revents & POLLPRI ) ) )
+			result = raw1394_loop_iterate( handle );
 	}
 	return NULL;
 }
@@ -631,9 +628,9 @@ bool dv1394Reader::StartThread()
 	currentFrame = NULL;
 	if ( Open() && StartReceive() )
 	{
-		pthread_create( &thread, NULL, Thread, this );
-		pthread_mutex_unlock( &mutex );
 		isRunning = true;
+		pthread_create( &thread, NULL, ThreadProxy, this );
+		pthread_mutex_unlock( &mutex );
 		return true;
 	}
 	else
@@ -652,11 +649,6 @@ bool dv1394Reader::StartThread()
     canceled, we turn off iso receive and close the ieee1394
     subsystem.  We also remove all frames in the outFrames queue that
     have not been processed until now.
- 
-    \bugs It is not clear what happens if no data is being sent by the
-    camcorder. Will we still hit the pthread_testcancel function in
-    this case?
- 
 */
 
 void dv1394Reader::StopThread()
@@ -664,14 +656,13 @@ void dv1394Reader::StopThread()
 	if ( isRunning )
 	{
 		pthread_mutex_lock( &mutex );
-		pthread_cancel( thread );
+		isRunning = false;
 		pthread_join( thread, NULL );
+		pthread_mutex_unlock( &mutex );
 		StopReceive();
 		Close();
 		Flush();
-		pthread_mutex_unlock( &mutex );
 	}
-	isRunning = false;
 }
 
 
@@ -752,12 +743,21 @@ void dv1394Reader::StopReceive()
 bool dv1394Reader::Handler( int handle )
 {
 	struct dv1394_status dvst;
-
-	if ( ioctl( handle, DV1394_WAIT_FRAMES, 1 ) )
+	struct pollfd pol;
+	int result;
+		
+	pol.fd = m_dv1394_fd;
+	pol.events = POLLIN | POLLERR | POLLHUP;
+	while ( ( result = poll( &pol, 1, 200 ) ) < 0 )
 	{
-		perror( "error: ioctl WAIT_FRAMES" );
-		return false;
+		if ( !( errno == EAGAIN || errno == EINTR ) )
+		{
+			perror( "error: dv1394 poll" );
+			return false;
+		}
 	}
+	if ( result == 0 )
+		return true;
 
 	if ( ioctl( handle, DV1394_GET_STATUS, &dvst ) )
 	{
@@ -837,15 +837,19 @@ bool dv1394Reader::Handler( int handle )
     but only in the pthread_testcancel() function.
  
 */
-void* dv1394Reader::Thread( void* arg )
+void* dv1394Reader::ThreadProxy( void* arg )
 {
-	dv1394Reader * theReader = ( dv1394Reader* ) arg;
+	dv1394Reader* self = static_cast< dv1394Reader* >( arg );
+	return self->Thread();
+}
 
-	while ( true )
+void* dv1394Reader::Thread( )
+{
+
+	while ( isRunning )
 	{
-		if ( ! Handler( theReader->m_dv1394_fd ) )
+		if ( ! Handler( m_dv1394_fd ) )
 			break;
-		pthread_testcancel();
 	}
 	return NULL;
 }
@@ -986,7 +990,7 @@ void AVC::Noop( void )
 {
 	struct pollfd raw1394_poll;
 	raw1394_poll.fd = raw1394_get_fd( avc_handle );
-	raw1394_poll.events = POLLIN;
+	raw1394_poll.events = POLLIN | POLLPRI;
 	raw1394_poll.revents = 0;
 	if ( poll( &raw1394_poll, 1, 100 ) > 0 )
 	{
@@ -1259,17 +1263,17 @@ void dv1394Writer::SendFrame( Frame &frame )
 
 		struct dv1394_init setup =
 		    {
-    api_version:
-			    DV1394_API_VERSION,
-    channel:
-			    m_channel,
-    n_frames:
-			    m_nBuffers,
-    format:
-			    ( isPAL ? DV1394_PAL : DV1394_NTSC ),
-    cip_n : m_cip_n,
-    cip_d : m_cip_d,
-    syt_offset : m_syt_offset
+			api_version:
+						DV1394_API_VERSION,
+			channel:
+						m_channel,
+			n_frames:
+						m_nBuffers,
+			format:
+						( isPAL ? DV1394_PAL : DV1394_NTSC ),
+			cip_n : m_cip_n,
+			cip_d : m_cip_d,
+			syt_offset : m_syt_offset
 		    };
 		ioctl( m_fd, DV1394_INIT, &setup );
 	}
