@@ -33,19 +33,19 @@ class Frame;
 
 class IEEE1394Reader
 {
-private:
+protected:
 	/// the number of frames that had to be thrown away because
 	/// our inFrames queue did not contain available frames
-	static int droppedFrames;
+	int droppedFrames;
 
 	/// a pointer to the frame which is currently been transmitted
-	static Frame	*currentFrame;
+	Frame	*currentFrame;
 
 	/// a list of empty frames
-	static deque < Frame* > inFrames;
+	deque < Frame* > inFrames;
 
 	/// a list of already received frames
-	static deque < Frame* > outFrames;
+	deque < Frame* > outFrames;
 
 public:
 
@@ -78,8 +78,8 @@ public:
 	virtual bool Open( void ) = 0;
 	virtual void Close( void ) = 0;
 
-	static bool WaitForAction( );
-	static void TriggerAction( );
+	bool WaitForAction( );
+	void TriggerAction( );
 
 	virtual bool StartReceive( void ) = 0;
 	virtual void StopReceive( void ) = 0;
@@ -93,12 +93,12 @@ protected:
 
 	/// this mutex protects capture related variables that could possibly
 	/// accessed from two threads at the same time
-	static pthread_mutex_t mutex;
+	pthread_mutex_t mutex;
 
 	// This condition and mutex are used to indicate when new frames are
 	// received
-	static pthread_mutex_t condition_mutex;
-	static pthread_cond_t condition;
+	pthread_mutex_t condition_mutex;
+	pthread_cond_t condition;
 
 	/// A state variable for starting and stopping thread
 	bool isRunning;
@@ -115,7 +115,7 @@ private:
 	int	port;
 
 	/// the handle to the ieee1394 subsystem
-	static raw1394handle_t handle;
+	raw1394handle_t handle;
 
 public:
 
@@ -128,10 +128,12 @@ public:
 	void StopReceive( void );
 	bool StartThread( void );
 	void StopThread( void );
+	int Handler( int channel, size_t length, quadlet_t *data );
+	void *Thread();
 
 private:
-	static int Handler( raw1394handle_t handle, int channel, size_t length, quadlet_t *data );
-	static void* Thread( void *arg );
+	static int HandlerProxy( raw1394handle_t handle, int channel, size_t length, quadlet_t *data );
+	static void* ThreadProxy( void *arg );
 };
 
 
@@ -139,8 +141,8 @@ class dv1394Reader: public IEEE1394Reader
 {
 private:
 
-	static unsigned char *m_dv1394_map;
-	static int m_dv1394_fd;
+	unsigned char *m_dv1394_map;
+	int m_dv1394_fd;
 
 public:
 
@@ -153,10 +155,11 @@ public:
 	void StopReceive( void );
 	bool StartThread( void );
 	void StopThread( void );
+	void* Thread( );
 
 private:
-	static bool Handler( int handle );
-	static void* Thread( void *arg );
+	bool Handler( int handle );
+	static void* ThreadProxy( void *arg );
 };
 
 
@@ -168,10 +171,10 @@ private:
 
 	/// this mutex protects avc related variables that could possibly
 	/// accessed from two threads at the same time
-	static pthread_mutex_t avc_mutex;
+	pthread_mutex_t avc_mutex;
 
 	/// the handle to the ieee1394 subsystem
-	static raw1394handle_t avc_handle;
+	raw1394handle_t avc_handle;
 
 public:
 	AVC( int crd = 0 );
