@@ -25,6 +25,8 @@
 #include "image_create.h"
 #include "page_magick.h"
 #include "message.h"
+#include <string.h>
+#include <stdio.h>
 
 extern "C"
 {
@@ -81,7 +83,7 @@ public:
 		GtkWidget * label = gtk_label_new( _( "Frames " ) );
 		gtk_widget_show( label );
 
-		GtkObject *frame_counter_adj = gtk_adjustment_new( frames, 0, 1000, 1, 10, 10 );
+		GtkObject *frame_counter_adj = gtk_adjustment_new( frames, 0, 999999, 1, 10, 10 );
 		frame_counter = gtk_spin_button_new( GTK_ADJUSTMENT( frame_counter_adj ), 1, 0 );
 		gtk_widget_show( frame_counter );
 		gtk_widget_set_usize( frame_counter, 60, -2 );
@@ -458,6 +460,7 @@ class ImageCreateFromFile : public ImageCreateColourRange
 protected:
 	static char file[ PATH_MAX + NAME_MAX ];
 	GtkWidget *file_entry;
+	int count;
 
 public:
 	char *GetDescription( ) const
@@ -467,22 +470,49 @@ public:
 
 	void CreateFrame( uint8_t *pixels, int width, int height, double position, double frame_delta )
 	{
-		if ( position == 0 )
+		GError* gerror = NULL;
+		GdkPixbuf* still = NULL;
+		
+		// Determine if this is an image sequence
+		if ( strchr( file, '%' ) != NULL )
 		{
-			GError * gerror = NULL;
-			GdkPixbuf *splash = gdk_pixbuf_new_from_file( file, &gerror );
-			if ( gerror != NULL )
+			char full[ PATH_MAX + NAME_MAX ];
+			int gap = 0;
+		
+			// Permit gaps in the file number sequence up to 100 difference
+			while ( gap < 100 )
 			{
-				modal_message( gerror->message );
-				g_error_free( gerror );
-			}
-			else
-			{
-				GdkPixbuf *image = gdk_pixbuf_scale_simple( splash, width, height, GDK_INTERP_HYPER );
-				memcpy( pixels, gdk_pixbuf_get_pixels( image ), width * height * 3 );
-				g_object_unref( splash );
-				g_object_unref( image );
+				struct stat buf;
+					
+				snprintf( full, PATH_MAX + NAME_MAX, file, count++ );
+				if ( stat( full, &buf ) == 0 )
+					break;
+				else
+					gap ++;
 			}
+			
+			// If successfully obtained a new file
+			if ( gap < 100 )
+				still = gdk_pixbuf_new_from_file( full, &gerror );
+		}
+		// Otherwise, import single image just once
+		else if ( position == 0 )
+		{
+			still = gdk_pixbuf_new_from_file( file, &gerror );
+		}
+		// If gdk-pixbuf loader generated an error
+		if ( gerror != NULL )
+		{
+			modal_message( gerror->message );
+			g_error_free( gerror );
+		}
+		// Otherwise, if there is a pixbuf
+		else if ( still != NULL )
+		{
+			GdkPixbuf *image = gdk_pixbuf_scale_simple( still, width, height, GDK_INTERP_HYPER );
+			memcpy( pixels, gdk_pixbuf_get_pixels( image ), width * height * 3 );
+			g_object_unref( still );
+			g_object_unref( image );
 		}
 	}
 
@@ -501,6 +531,11 @@ public:
 		gtk_table_attach( GTK_TABLE( table ), label, 0, 1, 1, 2, ( GtkAttachOptions ) ( 0 ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 		gtk_table_attach( GTK_TABLE( table ), file_entry, 1, 2, 1, 2, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
 
+		GtkWidget *tip_label = gtk_label_new( _( "TIP: use a format specifier in the file name to import from an image sequence. For example: gap-%06d.png." ) );
+		gtk_label_set_line_wrap( GTK_LABEL( tip_label ), TRUE );
+		gtk_widget_show( tip_label );
+		gtk_table_attach( GTK_TABLE( table ), tip_label, 0, 2, 2, 3, ( GtkAttachOptions ) ( GTK_EXPAND | GTK_FILL ), ( GtkAttachOptions ) ( 0 ), 0, 0 );
+
 		gtk_widget_show( table );
 		gtk_container_add( GTK_CONTAINER( bin ), table );
 	}
@@ -527,6 +562,7 @@ public:
 
 		if ( !strcmp( file, "" ) )
 			throw _( "No image file name specified - aborting." );
+		count = 0;
 	}
 };
 
