@@ -545,7 +545,7 @@ void KinoCommon::insertFile( )
 {
 	changePageRequest( PAGE_EDITOR );
 	char * filename = this->getFileToOpen( _( "Choose a DV or SMIL file to insert" ) );
-	if ( strcmp( filename, "" ) )
+	if ( filename && strcmp( filename, "" ) )
 	{
 		switch ( checkFile( filename ) )
 		{
@@ -583,7 +583,7 @@ void KinoCommon::appendFile( )
 {
 	changePageRequest( PAGE_EDITOR );
 	char * filename = this->getFileToOpen( _( "Choose a DV or SMIL file to append" ) );
-	if ( strcmp( filename, "" ) )
+	if ( filename && strcmp( filename, "" ) )
 	{
 		switch ( checkFile( filename ) )
 		{
@@ -626,7 +626,7 @@ void KinoCommon::loadFile( )
 	changePageRequest( PAGE_EDITOR );
 	char * filename = this->getFileToOpen( _( "Choose a DV or SMIL file" ) );
 
-	if ( strcmp( filename, "" ) )
+	if ( filename && strcmp( filename, "" ) )
 	{
 		switch ( checkFile( filename ) )
 		{
@@ -678,8 +678,8 @@ bool KinoCommon::savePlayListAs( )
 {
 	bool result = false;
 	//changePageRequest( PAGE_EDITOR );
-	char *filename = this->getFileToOpen( _( "Save the movie as SMIL" ) );
-	if ( strcmp( filename, "" ) )
+	char *filename = this->getFileToSave( _( "Save the movie as SMIL" ) );
+	if ( filename && strcmp( filename, "" ) )
 	{
 		// See if it exists already and warn user
 		FILE *f = fopen( filename, "r" );
@@ -708,8 +708,8 @@ void KinoCommon::savePlayListAsEli( )
 
 	this->getPlayList() ->GetFrame( g_currentFrame, frame );
 	changePageRequest( PAGE_EDITOR );
-	char *filename = this->getFileToOpen( _( "Save the movie as ELI" ) );
-	if ( strcmp( filename, "" ) )
+	char *filename = this->getFileToSave( _( "Save the movie as ELI" ) );
+	if ( filename && strcmp( filename, "" ) )
 	{
 		if ( this->getPlayList() ->SavePlayListEli( filename,
 		        frame.IsPAL() ) == false )
@@ -744,12 +744,88 @@ void KinoCommon::saveFrame( )
 	}
 	else
 	{
-		char * filename = common->getFileToOpen( _( "Save Still Frame" ) );
-		if ( strcmp( filename, "" ) )
+		char * filename = common->getFileToSave( _( "Save Still Frame" ) );
+		if ( filename && strcmp( filename, "" ) )
 			common->saveFrame( common->g_currentFrame, filename );
 	}
 }
 
+#ifdef HAVE_GTK24
+/**
+
+Used by update_preview_cb to generate a file preview in the File->Open dialog
+
+*/
+gboolean generate_file_preview( GtkWidget *preview, const char *filename )
+{
+	FileHandler *mediaFile = NULL;
+	try
+	{
+		if ( strcmp( filename, "" ) )
+		{
+			switch ( common->checkFile( const_cast<char*>( filename ) ) )
+			{
+				case AVI:
+					mediaFile = new AVIHandler();
+					break;
+				case RAW_DV:
+					mediaFile = new RawHandler();
+					break;
+				case QT:
+#ifdef HAVE_LIBQUICKTIME
+					mediaFile = new QtHandler();
+#endif
+					break;
+			}
+		}
+	
+		if ( mediaFile && mediaFile->Open( filename ) )
+		{
+			// Force GDK displayer because freeing the XvDisplayer will
+			// causing nothing to show
+			Frame& frame = *GetFramePool()->GetFrame();
+			int frameNum = mediaFile->GetTotalFrames() < 61 ? ( mediaFile->GetTotalFrames() / 2 ) : 60;
+			unsigned char *pixels = (unsigned char*)malloc( 720*576*4 );
+			mediaFile->GetFrame( frame, frameNum );
+			GdkDisplayer display( preview, frame.GetWidth(), frame.GetHeight(), frame.IsWide() );
+			frame.ExtractPreviewRGB( pixels );
+			display.put( pixels );
+			free( pixels );
+			GetFramePool()->DoneWithFrame( &frame );
+			delete mediaFile;
+			return true;
+		}
+	}
+	catch ( string s )
+	{
+		cerr << "generate_file_preview exception: " << s << endl;
+	}
+	delete mediaFile;
+	return false;
+}
+
+/**
+
+Callback used by KinoCommon::getFileToOpen to generate file previews
+
+*/
+
+void update_preview_cb (GtkFileChooser *file_chooser, gpointer data)
+{
+	GtkWidget *preview;
+	char *filename;
+	gboolean have_preview;
+
+	preview = GTK_WIDGET( data );
+	filename = gtk_file_chooser_get_preview_filename( file_chooser );
+
+	if ( filename && !g_file_test( filename, G_FILE_TEST_IS_DIR )) {
+		have_preview = generate_file_preview( preview, filename );
+		gtk_file_chooser_set_preview_widget_active( file_chooser,
+						have_preview );
+	}
+}
+
 /** Handles the modal dialog for collecting a file to open. The file is not opened,
 	but returned by this method.
 
@@ -757,6 +833,123 @@ void KinoCommon::saveFrame( )
 	\return a string inidicating the selected file (an empty string denotes no selection)
 */
 
+char *KinoCommon::getFileToOpen( char *title )
+{
+	GtkWidget *dialog;
+	GtkDrawingArea *preview;
+	GtkFileFilter *filter;
+
+	dialog = gtk_file_chooser_dialog_new( title,
+				NULL,
+				GTK_FILE_CHOOSER_ACTION_OPEN,
+				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+				NULL );
+	
+	preview = ( GtkDrawingArea* )gtk_drawing_area_new();
+	gtk_widget_set_size_request( GTK_WIDGET(preview), 160, 120 );
+	gtk_file_chooser_set_preview_widget( GTK_FILE_CHOOSER(dialog),
+				GTK_WIDGET(preview) );
+	g_signal_connect( dialog, "update-preview",
+				G_CALLBACK(update_preview_cb), preview );
+
+	filter = gtk_file_filter_new();
+	gtk_file_filter_set_name( filter, "All Files" );
+	gtk_file_filter_add_pattern( filter, "*" );
+	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+
+	filter = gtk_file_filter_new();
+	gtk_file_filter_set_name( filter, "SMIL Files (*.smil)" );
+	gtk_file_filter_add_pattern( filter, "*.smil" );
+	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+
+	filter = gtk_file_filter_new();
+	gtk_file_filter_set_name( filter, "Digital Video Files (*.dv, *.dif)" );
+	gtk_file_filter_add_pattern( filter, "*.dv" );
+	gtk_file_filter_add_pattern( filter, "*.dif" );
+	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+
+	filter = gtk_file_filter_new();
+	gtk_file_filter_set_name( filter, "AVI Files (*.avi)" );
+	gtk_file_filter_add_pattern( filter, "*.avi" );
+	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+
+#ifdef HAVE_LIBQUICKTIME
+	filter = gtk_file_filter_new();
+	gtk_file_filter_set_name( filter, "Quicktime Files (*.mov)" );
+	gtk_file_filter_add_pattern( filter, "*.mov" );
+	gtk_file_chooser_add_filter( GTK_FILE_CHOOSER(dialog), filter );
+#endif
+
+	gtk_window_set_modal( GTK_WINDOW( dialog ), TRUE );
+	if ( last_directory == "" )
+	{
+		string directory = getPlayList() ->GetProjectDirectory( );
+		if ( directory != "" )
+			gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( directory + "/." ).c_str() );
+		last_directory = directory;
+	}
+	else
+	{
+		gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( last_directory + "/." ).c_str() );
+	}
+	if (gtk_dialog_run( GTK_DIALOG( dialog ) ) == GTK_RESPONSE_ACCEPT) {
+		const gchar *filename = gtk_file_chooser_get_filename(
+						GTK_FILE_CHOOSER( dialog ));
+		if ( filename )
+		{
+			strncpy( tempFileName, filename, sizeof(tempFileName) );
+			last_directory = directory_utils::get_directory_from_file( filename );
+		}
+		else
+			strcpy( tempFileName, "" );
+	} else
+		strcpy( tempFileName, "" );
+
+	gtk_widget_destroy( dialog );
+	return tempFileName;
+}
+
+char *KinoCommon::getFileToSave( char *title )
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_file_chooser_dialog_new(title,
+					NULL,
+					GTK_FILE_CHOOSER_ACTION_SAVE,
+					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+					NULL);
+	gtk_window_set_modal( GTK_WINDOW( dialog ), TRUE );
+	if ( last_directory == "" )
+	{
+		string directory = getPlayList() ->GetProjectDirectory( );
+		if ( directory != "" )
+			gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( directory + "/." ).c_str() );
+		last_directory = directory;
+	}
+	else
+	{
+		gtk_file_chooser_set_filename( GTK_FILE_CHOOSER( dialog ), ( char * ) ( last_directory + "/." ).c_str() );
+	}
+	if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
+		char *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		if ( filename )
+		{
+			strncpy (tempFileName, filename, sizeof(tempFileName));
+			g_free (filename);
+		}
+		else
+			strcpy( tempFileName, "" );
+	} else
+		strcpy(tempFileName, "");
+
+	gtk_widget_destroy (dialog);
+	return tempFileName;
+}
+
+#else /* HAVE_GTK24 */
+
 char *KinoCommon::getFileToOpen( char *title )
 {
 	GtkWidget *dialog = gtk_file_selection_new( title );
@@ -793,6 +986,13 @@ char *KinoCommon::getFileToOpen( char *title )
 	return tempFileName;
 }
 
+char *KinoCommon::getFileToSave( char *title)
+{
+	return getFileToOpen(title);
+}
+
+#endif
+
 /**	Determines the format of the file.
 
 	It is required that a file be at least 20 bytes for it to load.
@@ -1514,7 +1714,9 @@ void KinoCommon::videoShuttle( int angle )
 	{
 		toggleComponents( getComponentState(), false );
 
-		//gtk_range_set_value( this->video_shuttle, angle );
+		if ( ! Preferences::getInstance().dropFrame )
+			// this has bad thread interaction with dropFrame playback
+			gtk_range_set_value( this->video_shuttle, angle );
 		getCurrentPage() ->videoShuttle( angle );
 
 		commitComponentState();
@@ -1602,9 +1804,9 @@ void KinoCommon::toggleComponents( component_enum pattern, bool state )
 	{
 		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( video_play_button ), state );
 		if ( state )
-			gtk_image_set_from_file( GTK_IMAGE( lookup_widget( widget, "pixmap_play_pause" ) ), DATADIR "/kino/editor_pause.xpm" );
+			gtk_image_set_from_file( GTK_IMAGE( lookup_widget( widget, "pixmap_play_pause" ) ), DATADIR "/kino/stock_media-pause-16.png" );
 		else
-			gtk_image_set_from_file( GTK_IMAGE( lookup_widget( widget, "pixmap_play_pause" ) ), DATADIR "/kino/editor_play.xpm" );
+			gtk_image_set_from_file( GTK_IMAGE( lookup_widget( widget, "pixmap_play_pause" ) ), DATADIR "/kino/stock_media-play-16.png" );
 	}
 	if ( pattern & VIDEO_STOP )
 		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( video_stop_button ), state );
@@ -1784,7 +1986,7 @@ void KinoCommon::loadSplash( GtkDrawingArea *drawable )
 	GdkPixbuf *bgImage = gdk_pixbuf_new_from_data( background, GDK_COLORSPACE_RGB, FALSE, 8,
 						 width, height, width * 3, NULL, NULL );
 	fail_null( bgImage );
-	GdkPixbuf *splash = create_pixbuf( "kino/kino.jpeg" );
+	GdkPixbuf *splash = create_pixbuf( "kino/about.jpeg" );
 	if ( splash != NULL )
 	{
 		AspectRatioCalculator calc( width, height, gdk_pixbuf_get_width( splash ),
@@ -1947,7 +2149,7 @@ void KinoCommon::publishFrame()
 	}
 	else
 	{
-		char * filename = common->getFileToOpen( _( "Save Still Frame" ) );
+		char * filename = common->getFileToSave( _( "Save Still Frame" ) );
 		if ( strcmp( filename, "" ) )
 		{
 			std::ostringstream command;
