@@ -737,6 +737,14 @@ gboolean PageCapture::processKeyboard( GdkEventKey *event )
 		// Translate special keys to equivalent command
 		switch ( event->keyval )
 		{
+		case GDK_Home:
+			strcat( cmd, "gg");
+			ret = TRUE;
+			break;
+		case GDK_End:
+			strcat( cmd, "G");
+			ret = TRUE;
+			break;
 		case GDK_BackSpace:
 		case GDK_Left:
 			strcat( cmd, "h" );
@@ -1319,7 +1327,7 @@ void PageCapture::saveFrame()
 			im = scaled;
 		}
 
-		char *filename = common->getFileToOpen( _( "Save Still Frame" ) );
+		char *filename = common->getFileToSave( _( "Save Still Frame" ) );
 		if ( strcmp( filename, "" ) )
 		{
 			const std::string FileName( filename );
@@ -1355,10 +1363,11 @@ void PageCapture::showFrameInfo( int i )
 	GtkLabel *total = GTK_LABEL( lookup_widget( common->getWidget(), "position_label_total" ) );
 	string tc;
 	char msg[ 128 ] = "";
+	Frame *frame = getFrame();
 	
-	if ( isCapturing )
+	if ( isCapturing && frame )
 	{
-		common->getTime().setFramerate( getFrame()->GetFrameRate() );
+		common->getTime().setFramerate( frame->GetFrameRate() );
 		string tc = "<span size=\"x-large\">" + common->getTime().parseFramesToString( i, common->getTimeFormat() ) + "</span>";
 		gtk_label_set_markup( timecodeLabel, tc.c_str() );
 		gtk_widget_set_redraw_on_allocate( GTK_WIDGET( timecodeLabel ), FALSE );
@@ -1677,7 +1686,7 @@ extern "C"
 		g_nav_ctl.escaped = TRUE;
 		gtk_entry_set_editable( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_capture_file" ) ), TRUE );
 		gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "entry_capture_file" ) );
-		const char *filename = common->getFileToOpen( _("Choose a DV file") );
+		const char *filename = common->getFileToSave( _("Choose a DV file") );
 		if ( strcmp( filename, "" ) )
 			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_capture_file" ) ), filename );
 	}
