@@ -256,6 +256,7 @@ void PageEditor::stopNavigator()
 		pthread_join( audiothread, NULL );
 		pthread_join( videothread, NULL );
 		gdk_threads_enter();
+		getFrameDisplayer()->CloseSound();
 	}
 }
 
@@ -597,6 +598,22 @@ gboolean PageEditor::processKeyboard( GdkEventKey *event )
 		// Translate special keys to equivalent command
 		switch ( event->keyval )
 		{
+		case GDK_Home:
+			strcat( cmd, "gg");
+			ret = TRUE;
+			break;
+		case GDK_End:
+			strcat( cmd, "G");
+			ret = TRUE;
+			break;
+		case GDK_Page_Up:
+			strcat( cmd, "5^" );
+			ret = TRUE;
+			break;
+		case GDK_Page_Down:
+			strcat( cmd, "5$" );
+			ret = TRUE;
+			break;
 		case GDK_BackSpace:
 		case GDK_Left:
 			strcat( cmd, "h" );
@@ -1436,8 +1453,8 @@ extern "C"
 	
 	static void on_end_of_movie( )
 	{
-		if ( common->g_currentFrame == common->getPlayList()->GetNumFrames() - 1 ||
-			( common->g_currentFrame == 0 && ( g_nav_ctl.step < 0 || g_nav_ctl.rate < 0 ) ) )
+		if ( common->g_currentFrame >= common->getPlayList()->GetNumFrames() - 1 ||
+			( common->g_currentFrame <= 0 && ( g_nav_ctl.step < 0 || g_nav_ctl.rate < 0 ) ) )
 		{
 			gdk_threads_enter();
 			common->videoStop();
@@ -1561,8 +1578,6 @@ extern "C"
 					gdk_flush();
 					gdk_threads_leave();
 
-					on_end_of_movie();
-
 					// Determine how far from the next frame we really are
 					gettimeofday( &end, NULL );
 					int difference = ( ( start.tv_sec * 1000000 + start.tv_usec ) - ( end.tv_sec * 1000000 + end.tv_usec ) );
@@ -1583,13 +1598,15 @@ extern "C"
 					{
 						gettimeofday( &start, NULL );
 					}
-				}
+				} 
 
 				// update the lastFrame and lastPos variables
 				lastFrame = newFrame;
 
 				// Incrment the frame count
 				countFrames ++;
+				
+				on_end_of_movie();
 			}
 		}
 
@@ -1662,9 +1679,6 @@ extern "C"
 					showing = true;
 
 					TriggerVideoAction( );
-
-					on_end_of_movie();
-
 				}
 				else
 				{
