@@ -90,6 +90,7 @@ PageExport::~PageExport()
 void PageExport::start()
 {
 	cerr << ">> Starting Export" << endl;
+	gtk_notebook_set_page( GTK_NOTEBOOK( lookup_widget( common->getWidget(), "notebook_keyhelp" ) ), 3 );
 	this->getCurrentPage() ->start();
 	if ( !isExporting )
 	{
@@ -154,7 +155,11 @@ void PageExport::setCurrentMode( int mode )
 			this->clean();
 		currentMode = mode;
 		this->start();
-		this->activate();
+		
+		// Enable or disable the widgets - it calls our activate() and
+		// deactivate() and can control the storyboard whereas 
+		// Export::activate() can not!
+		common->activateWidgets();
 	}
 }
 
