@@ -76,15 +76,15 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 {
 	cerr << ">>> ExportAudio::doExport" << endl;
 	Frame& frame = *GetFramePool()->GetFrame();
-	//TODO: Fix filename issues.
-	char file[ 512 ];
+	gchar *file = NULL;
 	enum export_result status = EXPORT_RESULT_SUCCESS;
 
 	/* Check the filename */
-	strcpy( file, gtk_entry_get_text( fileEntry ) );
-	if ( !( strcmp( file, "" ) && strpbrk( file, " |`\"()" ) == NULL ) )
+	file = g_strdup( gtk_entry_get_text( fileEntry ) );
+	if ( !( strcmp( file, "" ) && strpbrk( file, "\'" ) == NULL ) )
 	{
-		modal_message( _( "You must enter a filename which doesn't contain special characters (spaces, quotes, pipes etc)." ) );
+		modal_message( _( "You must enter a filename which does not contain quotes." ) );
+		g_free( file );
 		return EXPORT_RESULT_FAILURE;
 	}
 
@@ -114,40 +114,40 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 	active_item = gtk_menu_get_active( audioFormat );
 	menuValue = g_list_index ( GTK_MENU_SHELL ( audioFormat ) ->children, active_item );
 
-	char outputtemplate[ 1024 ];
+	gchar *outputtemplate = NULL;
 	int resampleRate = 0;
 	kino_audio_pipe type = PIPE_AUDIO_WAV;
 
 	if ( menuValue == 0 )
 	{
-		sprintf( outputtemplate, "%s%%s.wav", file );
+		outputtemplate = g_strdup_printf( "%s%%s.wav", file );
 		resampleRate = outputFrequency;
 		type = PIPE_AUDIO_WAV;
 	}
 	else if ( menuValue == 1 )
 	{
-		sprintf( outputtemplate, "| sox -t .raw -r %d -c 2 -w -s - -r %d %s%%s.wav",
+		outputtemplate = g_strdup_printf( "| sox -t .raw -r %d -c 2 -w -s - -r %d \'%s\'%%s.wav",
 		         inputFrequency, outputFrequency, file );
 		resampleRate = inputFrequency;
 		type = PIPE_AUDIO_WAV;
 	}
 	else if ( menuValue == 2 )
 	{
-		sprintf( outputtemplate, "| mp2enc -r %d -o %s%%s.mp2",
+		outputtemplate = g_strdup_printf( "| mp2enc -r %d -o \'%s\'%%s.mp2",
 		         outputFrequency, file );
 		resampleRate = inputFrequency;
 		type = PIPE_AUDIO_WAV;
 	}
 	else if ( menuValue == 3 )
 	{
-		sprintf( outputtemplate, "| lame -r -s %d -x - -o %s%%s.mp3",
+		outputtemplate = g_strdup_printf( "| lame -r -s %d -x - -o \'%s\'%%s.mp3",
 		         inputFrequency / 1000, file );
 		resampleRate = inputFrequency;
 		type = PIPE_AUDIO_PCM;
 	}
 	else if ( menuValue == 4 )
 	{
-		sprintf( outputtemplate, "| oggenc - -o %s%%s.ogg", file );
+		outputtemplate = g_strdup_printf( "| oggenc - -o \'%s\'%%s.ogg", file );
 		resampleRate = inputFrequency;
 		type = PIPE_AUDIO_WAV;
 	}
@@ -163,7 +163,7 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 	for ( int sceneBegin = begin; sceneBegin <= end && exportPage->isExporting;
 	        scene ++ )
 	{
-		char full[ 1024 ];
+		gchar *full;
 		char sceneString[ 5 ];
 		int sceneEnd = end;
 
@@ -181,10 +181,12 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 		}
 
 		// expand the template to accomodate the scene splits
-		sprintf( full, outputtemplate, sceneString );
+		full = g_strdup_printf( outputtemplate, sceneString );
 
 		// output this scene
 		bool active = output->OpenAudio( full, channels, resampleRate, 2 );
+		g_free( full );
+		
 		if ( active )
 		{
 			for ( int i = sceneBegin; i <= sceneEnd && exportPage->isExporting;
@@ -220,6 +222,8 @@ ExportAudio::doExport( PlayList * playlist, int begin, int end, int every,
 		sceneBegin = sceneEnd + 1;
 	}
 
+	g_free( file );
+	g_free( outputtemplate );
 	delete resampler;
 	delete output;
 
@@ -235,7 +239,7 @@ extern "C"
 	on_button_export_audio_file_clicked    (GtkButton       *button,
                                             gpointer         user_data)
 	{
-		const char *filename = common->getFileToOpen( _("Enter a File Name to Save As") );
+		const char *filename = common->getFileToSave( _("Enter a File Name to Save As") );
 		gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "entry_export_audio_file" ) );
 		if ( strcmp( filename, "" ) )
 			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_export_audio_file" ) ), filename );
