@@ -303,7 +303,7 @@ extern "C"
 	on_button_export_avi_file_clicked    (GtkButton       *button,
                                             gpointer         user_data)
 	{
-		const char *filename = common->getFileToOpen( _("Enter a File Name to Save As") );
+		const char *filename = common->getFileToSave( _("Enter a File Name to Save As") );
 		gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "entry_export_avi_file" ) );
 		if ( strcmp( filename, "" ) )
 			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_export_avi_file" ) ), filename );
