@@ -74,22 +74,22 @@ ExportStills::doExport( PlayList * playlist, int begin, int end, int every,
 {
 	static unsigned char pixels[ FRAME_MAX_WIDTH * FRAME_MAX_HEIGHT * 4 ];
 	GdkPixbuf *image = NULL;
-	/* TODO: Fix these path handling functions */
-	char file[ 512 ];
-	char filename[ 512 ];
-	char extension[ 8 ];
+	gchar *file = NULL;
+	gchar *filename = NULL;
+	gchar *extension = NULL;
 	int i = -1;
 	GError *gerror = NULL;
 	char quality[ 8 ] = "75";
 	int extractOption;
 	bool isResample;
 
-	strcpy( file, gtk_entry_get_text( fileEntry ) );
+	file = g_strdup( gtk_entry_get_text( fileEntry ) );
 
 	/* Check for a valid filename */
 	if ( !strcmp( file, "" ) )
 	{
 		modal_message( _( "You must enter a filename." ) );
+		g_free( file );
 		return EXPORT_RESULT_FAILURE;
 	}
 
@@ -98,20 +98,18 @@ ExportStills::doExport( PlayList * playlist, int begin, int end, int every,
 	if ( adjust )
 		snprintf( quality, 8, "%d", ( int ) adjust->value );
 
-	/* parse the base filename and extension */
-	strcpy( filename, file );
-
 	/* make sure a file extension is supplied */
-	char *tmp = strrchr( filename, '.' );
+	char *tmp = strrchr( file, '.' );
 	if ( tmp == NULL )
 	{
 		modal_message( _( "You must enter a filename with an extension" ) );
+		g_free( file );
 		return EXPORT_RESULT_FAILURE;
 	}
 	else
 	{
-		tmp[ 0 ] = '\0';
-		strcpy( extension, strrchr( file, '.' ) );
+		extension = g_strdup( tmp );
+		tmp[0] = '\0';
 	}
 
 	/* get the frame extraction method */
@@ -170,11 +168,11 @@ ExportStills::doExport( PlayList * playlist, int begin, int end, int every,
 		}
 		
 		// save to image
-		sprintf( file, "%s_%08i%s", filename, i + 1, extension );
+		filename = g_strdup_printf( "%s_%06i%s", file, i + 1, extension );
 		if ( strncasecmp( extension + 1, "png", 8 ) == 0 )
-			gdk_pixbuf_save( image, file, "png", &gerror, NULL );
+			gdk_pixbuf_save( image, filename, "png", &gerror, NULL );
 		else
-			gdk_pixbuf_save( image, file, "jpeg", &gerror, "quality", quality, NULL );
+			gdk_pixbuf_save( image, filename, "jpeg", &gerror, "quality", quality, NULL );
 
 		if ( gerror != NULL )
 		{
@@ -182,9 +180,13 @@ ExportStills::doExport( PlayList * playlist, int begin, int end, int every,
 			g_error_free( gerror );
 		}
 		g_object_unref( image );
+		g_free( filename );
 	}
 
 	GetFramePool( ) ->DoneWithFrame( &frame );
+	
+	g_free( file );
+	g_free( extension );
 
 	if ( !exportPage->isExporting )
 		return EXPORT_RESULT_ABORT;
@@ -200,7 +202,7 @@ extern "C"
 	on_button_export_stills_file_clicked    (GtkButton       *button,
                                             gpointer         user_data)
 	{
-		const char *filename = common->getFileToOpen( _("Enter a File Name to Save As") );
+		const char *filename = common->getFileToSave( _("Enter a File Name to Save As") );
 		gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "entry_export_stills_file" ) );
 		if ( strcmp( filename, "" ) )
 			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_export_stills_file" ) ), filename );
