@@ -184,7 +184,7 @@ extern "C"
 	on_button_magick_file_clicked    (GtkButton       *button,
                                             gpointer         user_data)
 	{
-		const char *filename = common->getFileToOpen( _("Enter a File Name to Save As") );
+		const char *filename = common->getFileToSave( _("Enter a File Name to Save As") );
 		gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "entry_magick_file" ) );
 		if ( strcmp( filename, "" ) )
 			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_magick_file" ) ), filename );
@@ -232,7 +232,7 @@ extern "C"
 											gpointer         user_data)
 	{
 		common->getTime().parseValueToString( gtk_entry_get_text( entry ), common->getTimeFormat() );
-		GtkSpinButton *spinbutton = GTK_SPIN_BUTTON( lookup_widget( GTK_WIDGET( entry ), "spinbutton_magick_start" ) );
+		GtkSpinButton *spinbutton = GTK_SPIN_BUTTON( lookup_widget( GTK_WIDGET( entry ), "spinbutton_magick_end" ) );
 		gtk_spin_button_set_value( spinbutton, common->getTime().getFrames() );
 		on_spinbutton_magick_end_value_changed( spinbutton, NULL );
 	}
@@ -268,7 +268,7 @@ void *Plugin::Find( char *symbol )
 	return dlsym( ptr, symbol );
 }
 
-char *Plugin::GetError( )
+const char *Plugin::GetError( )
 {
 	return dlerror();
 }
@@ -607,7 +607,7 @@ public:
 	virtual void Initialise( PageMagickInfo * )
 	{ }
 	;
-	virtual void GetFrame( int16_t **audio, int i, int samples )
+	virtual void GetFrame( int16_t **audio, int i, int& samples )
 	{ }
 	;
 	virtual void Close()
@@ -794,7 +794,7 @@ void PageMagickCreate::Initialise( PageMagickInfo *info )
 	}
 
 	info->anteFrame = info->begin - 1;
-	info->postFrame = info->begin + 1;
+	info->postFrame = info->begin;
 
 	creator = info->GetCommon() ->getPageMagick() ->GetImageCreate();
 	if ( creator != NULL )
@@ -922,8 +922,8 @@ void PageMagickTransition::PreGetFrame( )
 	if ( animateKey )
 	{
 		info->GetPostFrame( keyFrame );
-		info->postFrame ++;
 	}
+	info->postFrame ++;
 }
 
 void PageMagickTransition::GetFrame( uint8_t *pixels, int i )
@@ -956,6 +956,10 @@ public:
 	void Initialise( PageMagickInfo *info );
 	void GetFrame( uint8_t *pixels, int i );
 	bool ChangesImage( );
+	void PreGetFrame( )
+	{
+		info->postFrame ++;
+	}
 };
 
 void PageMagickFilter::Initialise( PageMagickInfo *info )
@@ -993,7 +997,7 @@ private:
 	GDKAudioFilter *filter;
 public:
 	void Initialise( PageMagickInfo *info );
-	void GetFrame( int16_t **audio, int i, int samples );
+	void GetFrame( int16_t **audio, int i, int& samples );
 };
 
 void PageMagickAudioFilter::Initialise( PageMagickInfo *info )
@@ -1006,7 +1010,7 @@ void PageMagickAudioFilter::Initialise( PageMagickInfo *info )
 		throw _( "Invalid audio filter selected" );
 }
 
-void PageMagickAudioFilter::GetFrame( int16_t **audio, int i, int samples )
+void PageMagickAudioFilter::GetFrame( int16_t **audio, int i, int& samples )
 {
 	// Sanity checks ...
 	if ( !filter )
@@ -1029,7 +1033,7 @@ public:
 	PageMagickAudioTransition();
 	virtual ~PageMagickAudioTransition();
 	void Initialise( PageMagickInfo *info );
-	void GetFrame( int16_t **audio, int i, int samples );
+	void GetFrame( int16_t **audio, int i, int& samples );
 };
 
 PageMagickAudioTransition::PageMagickAudioTransition()
@@ -1055,7 +1059,7 @@ void PageMagickAudioTransition::Initialise( PageMagickInfo *info )
 		throw _( "Invalid audio transition selected" );
 }
 
-void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int samples )
+void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int& samples )
 {
 	// Sanity checks ...
 	if ( !transition )
@@ -1067,7 +1071,7 @@ void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int samples )
 	// In truth, even the aframes should be resampled to original aframes frequency... (fun, fun, fun)
 	Frame* infoFrame = GetFramePool()->GetFrame();
 	AudioInfo ainfo;
-	common->getPlayList()->GetFrame( i, *( infoFrame ) );
+	common->getPlayList()->GetFrame( info->GetPostFrame() - 1, *( infoFrame ) );
 	infoFrame->GetAudioInfo( ainfo );
 	if ( ainfo.channels )
 	{
@@ -1075,6 +1079,8 @@ void PageMagickAudioTransition::GetFrame( int16_t **audio, int i, int samples )
 		                                AUDIO_RESAMPLE_SRC_SINC_BEST_QUALITY, info->frequency );
 		resampler->Resample( *infoFrame );
 		int16_t *p = resampler->output;
+		if ( resampler->size / info->channels / 2 < samples )
+			samples = resampler->size / info->channels / 2;
 		for ( int s = 0; s < samples; s++ )
 			for ( int c = 0; c < info->channels; c++ )
 				audio_buffers[ c ][ s ] = *p++;
@@ -1441,6 +1447,7 @@ void PageMagick::start()
 	}
 
 	audio_transitions.SelectionChange();
+	gtk_notebook_set_page( GTK_NOTEBOOK( lookup_widget( common->getWidget(), "notebook_keyhelp" ) ), 3 );
 	gtk_check_menu_item_set_active( GTK_CHECK_MENU_ITEM( lookup_widget( common->getWidget(), "menuitem_fx" ) ), TRUE );
 	
 	timeFormatChanged();
@@ -1593,9 +1600,11 @@ void PageMagick::StartPreview()
 				}
 			}
 
-			for ( double i = ( double ) info->begin; i < ( double ) info->end && previewing; i += info->increment )
+			int frame_number = info->begin;
+			for ( double i = ( double ) info->begin; 
+				frame_number <= info->end && previewing; 
+				frame_number = ( int )( ( i += info->increment ) + 0.5 ) )
 			{
-				int frame_number = ( int ) i;
 				if ( info->reverse )
 					frame_number = info->end - ( ( int ) i - info->begin );
 
@@ -1818,9 +1827,11 @@ void PageMagick::StartRender()
 		bool change_image = image->ChangesImage( ) || frames->IsSynth( );
 
 		// For each frame
-		for ( double i = ( double ) info->begin; i < ( double )info->end && rendering; i += info->increment )
+		int frame_number = info->begin;
+		for ( double i = ( double ) info->begin; 
+			frame_number <= info->end && rendering; 
+			frame_number = ( int )( ( i += info->increment ) + 0.5 ) )
 		{
-			int frame_number = ( int ) i;
 			if ( info->reverse )
 				frame_number = info->end - ( ( int ) i - info->begin );
 
