@@ -367,27 +367,12 @@ extern "C"
 	on_button_trim_open_clicked( GtkButton       *button,
 	                             gpointer         user_data)
 	{
-		gtk_widget_grab_focus( lookup_widget( GTK_WIDGET( button ), "eventbox_trim" ) );
-		GtkWidget *dialog = gtk_file_selection_new( _("Choose a DV file")  );
-		gtk_window_set_modal( GTK_WINDOW( dialog ), TRUE );
-		g_signal_connect( G_OBJECT( GTK_FILE_SELECTION( dialog )->ok_button ),
-				"clicked", G_CALLBACK( gtk_widget_hide ),
-				(gpointer) dialog );
-		g_signal_connect( G_OBJECT( GTK_FILE_SELECTION( dialog )->cancel_button ),
-				"clicked", G_CALLBACK( gtk_widget_hide ),
-				(gpointer) dialog );
-		gtk_file_selection_set_filename( GTK_FILE_SELECTION( dialog ), common->getLastDirectory().c_str() );
-		gtk_dialog_run( GTK_DIALOG( dialog ) );
-		const gchar *filename = gtk_file_selection_get_filename( GTK_FILE_SELECTION( dialog ) );
-		/* If the user cancels, a directory will still be returned
-		If this is the case, return "" - the caller knows how to handle this */
-		if ( opendir( filename ) == NULL )
+		char *filename = common->getFileToOpen( _("Choose a DV file") );
+		if ( filename && strcmp( filename, "" ) )
 		{
-			common->setLastDirectory( directory_utils::get_directory_from_file( filename ) );
 			gtk_entry_set_text( GTK_ENTRY( lookup_widget( GTK_WIDGET( button ), "entry_trim_clip" ) ),
 				filename );
 		}
-		gtk_widget_destroy( dialog );
 	}
 
 	void
@@ -924,6 +909,7 @@ void PageTrim::stopNavigator()
 		pthread_join( audiothreadTrim, NULL );
 		pthread_join( videothreadTrim, NULL );
 		gdk_threads_enter();
+		getFrameDisplayer()->CloseSound();
 	}
 }
 
@@ -1287,6 +1273,10 @@ void PageTrim::videoEndOfMovie()
 
 void PageTrim::selectScene( int i )
 {
+	bool restartNavigator = ( g_nav_ctl.active == TRUE );
+	
+	stopNavigator();
+	
 	if ( mode == PAGE_TRIM_MODE_UPDATE )
 		// commit the changes and load a new scene
 		saveScene();
@@ -1311,7 +1301,9 @@ void PageTrim::selectScene( int i )
 
 		common->setCurrentScene( start_orig );
 	}
-
+	
+	if ( restartNavigator )
+		startNavigator();
 }
 
 int PageTrim::getSceneIndex()
@@ -1367,6 +1359,14 @@ gboolean PageTrim::processKeyboard( GdkEventKey *event )
 		// Translate special keys to equivalent command
 		switch ( event->keyval )
 		{
+		case GDK_Home:
+			strcat( cmd, "gg");
+			ret = TRUE;
+			break;
+		case GDK_End:
+			strcat( cmd, "G");
+			ret = TRUE;
+			break;
 		case GDK_BackSpace:
 		case GDK_Left:
 			strcat( cmd, "h" );
