@@ -289,7 +289,7 @@ string directory_utils::expand_directory( const string directory )
 	string_utils::split( directory, "/", items );
 	vector< string >::iterator item = items.begin( );
 
-	if ( *item == "~" )
+	if ( item != items.end( ) && *item == "~" )
 	{
 		output = getenv( "HOME" );
 		item ++;
