@@ -704,7 +704,8 @@ extern "C"
 		/* Remove the input callback */
 		// g_print( "In on preferences_dialog_destroy_event\n" );
 		JogShuttle::getInstance().deregisterCallback();
-		return FALSE;
+		gtk_widget_hide_on_delete( widget );
+		return TRUE;
 	}
 
 
@@ -743,7 +744,7 @@ extern "C"
 		strcpy( prefs.file, gtk_entry_get_text( GTK_ENTRY( widget ) ) );
 		widget = lookup_widget( dialog, "entry_frames" );
 		prefs.frames = atoi( gtk_entry_get_text( GTK_ENTRY( widget ) ) );
-		if ( prefs.frames <= 0 )
+		if ( prefs.frames < 0 )
 			prefs.frames = 7000;
 		widget = lookup_widget( dialog, "entry_every" );
 		prefs.every = atoi( gtk_entry_get_text( GTK_ENTRY( widget ) ) );
@@ -751,7 +752,7 @@ extern "C"
 			prefs.every = 1;
 		widget = lookup_widget( dialog, "entry_size" );
 		prefs.maxFileSize = atoi( gtk_entry_get_text( GTK_ENTRY( widget ) ) );
-		if ( prefs.maxFileSize <= 0 )
+		if ( prefs.maxFileSize < 0 )
 			prefs.maxFileSize = 2000;
 		widget = lookup_widget( dialog, "entry_interface" );
 		prefs.interface = atoi( gtk_entry_get_text( GTK_ENTRY( widget ) ) );
